@@ -34,7 +34,7 @@ class UniLogger:
         """
         Initialize an instance of UniLogger.
 
-        :param output_dir: directory to save the log file
+        :param output_dir: directory to saves the log file
         :param file_suffix: suffix of the log file
         :param verbose: if True, set the log level to DEBUG; otherwise, set to INFO
         :param logger_name: name of the logger
@@ -108,7 +108,8 @@ class UniLogger:
             full_message = f"{caller_class_name}.{caller_func_name}: {message}"
         else:
             full_message = f"{caller_func_name}: {message}"
-
+        
+        full_message = full_message.replace("UniLogger: ", "")
         self.logger.log(level, full_message)
 
     def notice(self, message: str):
